@@ -1,3 +1,3 @@
 from pokersolverquery.solver import BaseSolver, UPISolver, LoadedTree
-from pokersolverquery.building_blocks import Line
+from pokersolverquery.building_blocks import Line, TexasRange, Action
 
